// (c) Thomas Kamps, 2009
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the7 implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

#include "monopdgame.h"

#include "monopdfield.h"
#include "monopdcard.h"

MonopdGame::MonopdGame(QString t, QString n, QString d, int i) : MonopdTemplate(t,n,d) {
	MonopdField* f0 = new MonopdField(0);
	MonopdField* f1 = new MonopdField(1);
	MonopdField* f2 = new MonopdField(2);
	MonopdField* f3 = new MonopdField(3);

	f0->setName("ism");
	f1->setName("al");
	f2->setName("Kap");
	f3->setName("it");

	fields.append(f0);
	fields.append(f1);
	fields.append(f2);
	fields.append(f3);

	gameId = i;

	listed = true;
}

MonopdGame::~MonopdGame() {
	while (fields.size() > 0) {
		MonopdField* f = fields.value(0);
		fields.removeAll(f);
		delete f;
	}
	while (cards.size() > 0) {
		MonopdCard* c = cards.value(0);
		cards.removeAll(c);
		delete c;
	}
	while (players.size() > 0) {
		players.removeAll(players.value(0));
	}
}

//Returns the Field with given id. If no such field exists, one wil be createed and returned
MonopdField* MonopdGame::getField(int id) {
	for (int i = 0; i < fields.size(); i++)
		if (fields.value(i)->getId() == id) return fields.value(i);
	MonopdField* f = new MonopdField(id);
	fields.append(f);
	return f;
}

//Returns the Player with given id. If no such Player exists 0 will be returned
Player* MonopdGame::getPlayer(int id) {
	if (id == -1) return 0;
	for (int i = 0; i < players.size(); i++)
		if (players.value(i)->getId() == id) return players.value(i);
	return 0;
}

Player* MonopdGame::getPlayerFromList(int num) {
	if (num < 0) return 0;
	if (num >= players.size()) return 0;
	return players.value(num);
}

bool MonopdGame::hasPlayer(int id) {
	if (id == -1) return true;
	for (int i = 0; i < players.size(); i++)
		if (players.value(i)->getId() == id) return true;
	return false;
}

MonopdCard* MonopdGame::getCard(int id, bool create) {
	MonopdCard* c = 0;
	for (int i = 0; i < cards.size(); i++) {
		MonopdCard* crd = cards.value(i);
		if (crd->getId() == id) return crd;
	}
	if (create) {
		c = new MonopdCard(id);
		cards.append(c);
	}
	return c;
}

MonopdCard* MonopdGame::getCardFromList(int i) {
	if (i < 0) return 0;
	if (i >= cards.size()) return 0;
	return cards.value(i);
}

int MonopdGame::getGameId() {
	return gameId;
}

QString MonopdGame::getStatus() {
	return status;
}

bool MonopdGame::getCanBeJoined() {
	return canBeJoined;
}

int MonopdGame::getNumPlayer() {
	return numPlayer;
}

int MonopdGame::getMinPlayer() {
	return minPlayer;
}

int MonopdGame::getmaxPlayer() {
	return maxPlayer;
}

int MonopdGame::getMaster() {
	return master;
}

int MonopdGame::getNumFields() {
	return fields.size();
}

int MonopdGame::getNumCards() {
	return cards.size();
}

bool MonopdGame::getListed() {
	return listed;
}

void MonopdGame::addPlayer(Player* p) {
	if (p == 0) return;
	int s = players.size();
	players.append(p);
	s = players.size();
}

void MonopdGame::removePlayer(Player* p) {
	if (p == 0) return;
	int s = players.size();
	players.removeAll(p);
	s = players.size();
}

void MonopdGame::setGameId(int id) {
	gameId = id;
}

void MonopdGame::setStatus(QString s) {
	status = s;
}

void MonopdGame::setCanBeJoined(bool cbj) {
	canBeJoined = cbj;
}

void MonopdGame::setNumPlayer(int np) {
	numPlayer = np;
}

void MonopdGame::setMinPlayer(int mp) {
	minPlayer = mp;
}

void MonopdGame::setMaxPlayer(int mp) {
	maxPlayer = mp;
}

void MonopdGame::setMaster(int m) {
	master = m;
}

void MonopdGame::setListed(bool l) {
	listed = l;
}
